==> foundation-2.6.1.tgz: package/ZoomIn/ZoomIn.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const ZoomIn = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M56.774 10.391c-17.679 0-32 14.329-32 32a31.845 31.845 0 004.588 16.517L13.846 74.423l.054.054c-1.656 1.585-2.673 3.835-2.673 6.378-.001 4.913 3.913 8.755 8.821 8.754 2.507-.001 4.749-1.004 6.349-2.636l.039.039 16.008-16.009a31.865 31.865 0 0014.33 3.388c17.68 0 32-14.327 32-32-.001-17.671-14.321-32-32-32zm.194 51.417c-11.05 0-20-8.954-20-20 0-11.044 8.951-20 20-20 11.05 0 20 8.955 20 20 0 11.046-8.95 20-20 20z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M68.751 37.111v-.03l-7.076.008-.009-7.058a1.57 1.57 0 00-1.569-1.57c-.033 0-.064.008-.097.01h-6.084c-.033-.002-.064-.01-.097-.01-.867 0-1.569.702-1.569 1.57 0 .054.011.105.016.158l-.007 6.911-7.061.008c-.868 0-1.569.703-1.569 1.57v6.278c0 .867.702 1.569 1.569 1.569.054 0 .105-.011.158-.016l6.893.007-.009 7.034h.011l-.002.024c0 .868.703 1.569 1.569 1.569l.01-.001v.011h6.278v-.011a1.568 1.568 0 001.558-1.556h.03l-.009-7.059 7.028.007v-.011l.024.002c.868 0 1.569-.703 1.569-1.569v-6.278a1.564 1.564 0 00-1.555-1.567z"
  }));
});
ZoomIn.displayName = 'ZoomIn';
export const ZoomInDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/ZoomIn/ZoomIn.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var ZoomIn = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M56.774 10.391c-17.679 0-32 14.329-32 32a31.845 31.845 0 004.588 16.517L13.846 74.423l.054.054c-1.656 1.585-2.673 3.835-2.673 6.378-.001 4.913 3.913 8.755 8.821 8.754 2.507-.001 4.749-1.004 6.349-2.636l.039.039 16.008-16.009a31.865 31.865 0 0014.33 3.388c17.68 0 32-14.327 32-32-.001-17.671-14.321-32-32-32zm.194 51.417c-11.05 0-20-8.954-20-20 0-11.044 8.951-20 20-20 11.05 0 20 8.955 20 20 0 11.046-8.95 20-20 20z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M68.751 37.111v-.03l-7.076.008-.009-7.058a1.57 1.57 0 00-1.569-1.57c-.033 0-.064.008-.097.01h-6.084c-.033-.002-.064-.01-.097-.01-.867 0-1.569.702-1.569 1.57 0 .054.011.105.016.158l-.007 6.911-7.061.008c-.868 0-1.569.703-1.569 1.57v6.278c0 .867.702 1.569 1.569 1.569.054 0 .105-.011.158-.016l6.893.007-.009 7.034h.011l-.002.024c0 .868.703 1.569 1.569 1.569l.01-.001v.011h6.278v-.011a1.568 1.568 0 001.558-1.556h.03l-.009-7.059 7.028.007v-.011l.024.002c.868 0 1.569-.703 1.569-1.569v-6.278a1.564 1.564 0 00-1.555-1.567z"
  }));
});
ZoomIn.displayName = 'ZoomIn';
export var ZoomInDimensions = {
  height: 100,
  width: 100
};
